package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TdPropertyManager;

/**
 * 资产登记Service接口
 * 
 * @author ruoyi
 * @date 2024-04-26
 */
public interface ITdPropertyManagerService 
{
    /**
     * 查询资产登记
     * 
     * @param useId 资产登记主键
     * @return 资产登记
     */
    public TdPropertyManager selectTdPropertyManagerByUseId(String useId);

    /**
     * 查询资产登记列表
     * 
     * @param tdPropertyManager 资产登记
     * @return 资产登记集合
     */
    public List<TdPropertyManager> selectTdPropertyManagerList(TdPropertyManager tdPropertyManager);

    /**
     * 新增资产登记
     * 
     * @param tdPropertyManager 资产登记
     * @return 结果
     */
    public int insertTdPropertyManager(TdPropertyManager tdPropertyManager);

    /**
     * 修改资产登记
     * 
     * @param tdPropertyManager 资产登记
     * @return 结果
     */
    public int updateTdPropertyManager(TdPropertyManager tdPropertyManager);

    /**
     * 批量删除资产登记
     * 
     * @param useIds 需要删除的资产登记主键集合
     * @return 结果
     */
    public int deleteTdPropertyManagerByUseIds(String useIds);

    /**
     * 删除资产登记信息
     * 
     * @param useId 资产登记主键
     * @return 结果
     */
    public int deleteTdPropertyManagerByUseId(String useId);
}
